@@ -1,6 +1,6 @@
 """Parser - Parses the iTunes XML file
 
-(c) Steve Scholnick <steve@scholnick.net>
+(c) Steve Scholnick <scholnicks@gmail.com>
 MIT License
 
 See http://search.cpan.org/~dinomite/Mac-iTunes-Library-1.0/lib/Mac/iTunes/Library/XML.pm for Notes on the ridiculous format for the
@@ -10,7 +10,7 @@ Thanks to https://github.com/dinomite for deciphering the iTunes Library XML for
 
     https://github.com/scholnicks/itunes-library
 """
-import logging
+
 import xml.sax
 from . import library
 
@@ -26,21 +26,21 @@ class Parser(xml.sax.ContentHandler):
     def __init__(self):
         """Constructor"""
         xml.sax.ContentHandler.__init__(self)
-        self.stack         = []
-        self.inPlayLists   = False
-        self.inTracks      = False
-        self.inMusicFolder = False
-        self.inMajorVersion = False
-        self.inMinorVersion = False
+        self.stack                = []
+        self.inPlayLists          = False
+        self.inTracks             = False
+        self.inMusicFolder        = False
+        self.inMajorVersion       = False
+        self.inMinorVersion       = False
         self.inApplicationVersion = False
-        self.curKey        = ''
-        self.bufferString  = ''
-        self.item          = None
+        self.curKey               = ''
+        self.bufferString         = ''
+        self.item                 = None
 
-    def parse(self,pathToXMLFile):
+    def parse(self,pathToXMLFile,ignoreRemoteSongs):
         """parses the XML file passed in"""
-        self.lib = library.Library()
-        xml.sax.parse(open(pathToXMLFile,'r'), self)
+        self.lib = library.Library(ignoreRemoteSongs)
+        xml.sax.parse(open(pathToXMLFile,'r', encoding="utf8"), self)
         return self.lib
 
     def startElement(self, name, attrs):
@@ -96,7 +96,6 @@ class Parser(xml.sax.ContentHandler):
             if name == INTEGER_TYPE:
                 track = self.lib.getItemsById(self.bufferString)
                 if track:
-                    logging.debug("adding track %s",track)
                     self.item.addItem(track)
 
                 self.curKey       = ''
